import { validateType } from "package-json-validator";
import { createRule } from "../createRule.js";
import { formatErrors } from "../utils/formatErrors.js";
const rule = createRule({
  create(context) {
    return {
      "Program > JSONExpressionStatement > JSONObjectExpression > JSONProperty[key.value=type]"(node) {
        const typeValueNode = node.value;
        const typeValue = JSON.parse(
          context.sourceCode.getText(typeValueNode)
        );
        const errors = validateType(typeValue);
        if (errors.length) {
          context.report({
            data: {
              errors: formatErrors(errors)
            },
            messageId: "validationError",
            node: typeValueNode
          });
        }
      }
    };
  },
  meta: {
    docs: {
      category: "Best Practices",
      description: "Enforce that the `type` property is valid.",
      recommended: true
    },
    messages: {
      validationError: "Invalid type: {{ errors }}"
    },
    schema: [],
    type: "problem"
  }
});
export {
  rule
};
